==> aroundme_0_7_1.tar.tgz: am_0_7_core/aroundme/components/core/language/1/barnraiser_01/maint_permission.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once($language_path . 'inc/structure_common.inc.php');


// RESOURCE DESCRIPTIONS
$lang['resource']['user'][1] = 			"grant access to the membership maintainance page";
$lang['resource']['user'][2] = 			"allow the sending of external invitations";
$lang['resource']['user'][4] = 			"grant access to the permissions (this) page";
$lang['resource']['user'][8] = 			"allow the sending of external announcements";
$lang['resource']['user'][16] = 		"allow the sending of external announcements";
$lang['resource']['user'][32] = 		"grant access to abuse report management page";

$lang['resource']['module'][1] = 		"grant access to the groups module";
$lang['resource']['module'][2] = 		"grant access to module 2";
$lang['resource']['module'][4] = 		"grant access to module 3";
$lang['resource']['module'][8] = 		"grant access to module 4";
$lang['resource']['module'][16] = 		"grant access to module 5";
$lang['resource']['module'][32] = 		"grant access to module 6";


// HEADER
$lang['hdr_permissions'] = 				"default system permissions";


// SUBMIT BUTTONS
$lang['sub_update_permissions'] = 		"update default system permissions";

// TEXTS
$lang['txt_permissions_intro'] = 		"When a person registers they are given a role. You can then change their role in the member maintenance page. When a role is attached to a person they inherit a set of permissions as defined below. You can customise a persons permissions from the members maintenance page";
$lang['txt_module_intro'] = 			"You can grant access to each module installed in this system";

?>

==> aroundme_0_7_2.tar.tgz: am_0_7_core/aroundme/components/core/language/1/barnraiser_01/maint_permission.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once($language_path . 'inc/structure_common.inc.php');


// RESOURCE DESCRIPTIONS
$lang['resource']['user'][1] = 			"grant access to the membership maintainance page";
$lang['resource']['user'][2] = 			"allow the sending of external invitations";
$lang['resource']['user'][4] = 			"grant access to the permissions (this) page. WARNING: do not remove this from your role otherwise you will not be able to return here!";
$lang['resource']['user'][8] = 			"allow the sending of internal announcements";
$lang['resource']['user'][16] = 		"allow the sending of external announcements";
$lang['resource']['user'][32] = 		"grant access to abuse report management page";


// grp
$lang['resource']['module'][1] = 		"grant access to the groups section";
$lang['resource']['module'][2] = 		"grant access to groups maintainance page";
$lang['resource']['module'][4] = 		"allow creation of a group";
// lbr
$lang['resource']['module'][8] = 		"grant access to the wiki section";
$lang['resource']['module'][16] = 		"grant access to wiki-sets maintainance page";
$lang['resource']['module'][32] = 		"allow creation of a wiki-set";
// event
$lang['resource']['module'][64] = 		"grant access to the events section";
$lang['resource']['module'][128] = 		"grant access to events maintainance page";
$lang['resource']['module'][256] = 		"allow creation of an event";







// HEADER
$lang['hdr_options'] = 					"options";
$lang['hdr_permissions'] = 				"set permissions";


// SUBMIT BUTTONS
$lang['sub_update_permissions'] = 		"update system permissions";
$lang['sub_set_role'] = 				"select role";

// TEXTS
$lang['txt_permissions_intro'] = 		"When a person registers they are given a role. You can then change their role in the member maintenance page. When a role is attached to a person they inherit a set of permissions as defined below. You can customise a persons permissions from the members maintenance page";
$lang['txt_module_intro'] = 			"You can grant access to each module installed in this system";
$lang['txt_people_role'] = 				"There are SYS_KEYWORD_TOTAL people with this role in the system";

?>
